@@ -4,7 +4,17 @@ import string
 import sys
 import time
 
-__all__ = ["get_event_loop", "Constant", "MISS_OBJECT", "gen_random_time_id", "gen_random_str_id", "parse_error"]
+from dataclasses import dataclass
+
+__all__ = [
+    "get_event_loop",
+    "Constant",
+    "Event",
+    "MISS_OBJECT",
+    "gen_random_time_id",
+    "gen_random_str_id",
+    "parse_error",
+]
 
 from typing import Optional, Tuple
 
@@ -13,7 +23,7 @@ _STR_LD = string.ascii_letters + string.digits
 
 
 class Constant(object):
-    VERSION: str = "0.5.1"
+    VERSION: str = "0.5.3"
     USER_AGENT: str = "Python3"
     SOCKET_RECV_SIZE: int = 1024 ** 1
 
@@ -27,6 +37,19 @@ class Constant(object):
     CLIENT_EVENT_RESPONSE: int = 401
     SERVER_ERROR_RESPONSE: int = 501
 
+    EVENT_CLOSE_CONN: str = "event_close_conn"
+    PING_EVENT: str = "ping"
+    PONG_EVENT: str = "pong"
+
+
+@dataclass()
+class Event(object):
+    event_name: str
+    event_info: str
+
+    def to_tuple(self) -> Tuple[str, str]:
+        return self.event_name, self.event_info
+
 
 def _get_event_loop():
     if sys.version_info >= (3, 7):
